@@ -4,8 +4,6 @@ use std::mem;
 use async_trait::async_trait;
 use super::error::Result;
 
-
-//TODO: make this async so its actually fast lmao
 #[async_trait]
 pub trait ReadFromBigEndian : Sized
 {
@@ -13,6 +11,18 @@ pub trait ReadFromBigEndian : Sized
     async fn read_be<R : Read + std::marker::Unpin + std::marker::Send>(reader: &mut BufReader<R>) -> Result<Self>;
 }
 
+pub trait FromBigEndian : Sized
+{
+    fn from_be(int_bytes : Self) -> Self;
+}
+
+pub trait FromLittleEndian : Sized
+{
+    fn from_le(int_bytes : Self) -> Self;
+}
+
+ 
+
 macro_rules! be_impl {
     ($ty: ty, $size: tt) => {
         #[async_trait]
@@ -25,9 +35,27 @@ macro_rules! be_impl {
                 Ok(<$ty>::from_be_bytes(int_bytes))
             }
         }
+
+        impl FromBigEndian for $ty {
+            #[inline]
+            fn from_be(int_bytes : $ty) -> Self
+            {
+                <$ty>::from_be(int_bytes)
+            }
+        }
+        
+        impl FromLittleEndian for $ty {
+            #[inline]
+            fn from_le(int_bytes : $ty) -> Self
+            {
+                <$ty>::from_le(int_bytes)
+            }
+        }
     }
 }
 
+
+
 be_impl!(u8, (mem::size_of::<u8>()));
 be_impl!(u16, (mem::size_of::<u16>()));
 be_impl!(u32, (mem::size_of::<u32>()));
@@ -37,4 +65,5 @@ be_impl!(i16, (mem::size_of::<i16>()));
 be_impl!(i32, (mem::size_of::<i32>()));
 be_impl!(i64, (mem::size_of::<i64>()));
 be_impl!(usize, (mem::size_of::<usize>()));
-be_impl!(isize, (mem::size_of::<isize>()));
\ No newline at end of file
+be_impl!(isize, (mem::size_of::<isize>()));
+
